/*
 * Copyright 2010 Reef Angel / Roberto Imai
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

 /*
  * Updated by:  Curt Binder
  * Updates Released under Apache License, Version 2.0
  */

#ifndef	__RA_TOUCHLCD_H__
#define __RA_TOUCHLCD_H__

#include <Globals.h>
#include <Time.h>
#include <Wire.h>
#include <InternalEEPROM.h>
#include <Memory.h>
#include <SD.h>
#include <avr/pgmspace.h>
#include <avr/wdt.h>
#include "RA_TFT.h"
#include "Font.h"

class RA_TouchLCD
{

public:
    RA_TouchLCD();

	void Init();
	void SetBacklight(byte bl);
	void SetOrientation(byte O);
	byte GetOrientation();
	int GetWidth();
	int GetHeight();
	void Scroll(int offset);
	void FullClear(int color);
	void Clear(int color, int x1, int y1, int x2, int y2);
	void DrawPixel(int color, int x, int y);
	void DrawLine(int color, int x1, int y1, int x2, int y2);
	void DrawRectangle(int color, int x1, int y1, int x2, int y2, boolean fill);
	void DrawCircle(int color, int x, int y, int radius, boolean fill);
	void DrawRoundRect(int color, int x1, int y1, int x2, int y2, int radius, boolean fill);
	void DrawBMP(int ix, int iy, const prog_uchar *iPtr);
	void DrawBMP(int ix, int iy, const prog_uchar *iPtr, byte overridecolor_msb, byte overridecolor_lsb);
	void DrawSDImage(char *bmp, int x, int y);
	void DrawSDRawImage(char *bmp, int x, int y, int w, int h);
	void DrawDateTime(int x, int y, boolean militarytime, FontClass Font);
	void DrawRelayStatus(int x, int y, boolean status);
	void DrawAlertFlag(byte position, const prog_uchar *iPtr);
	void DrawFlags(byte Flags);
	
private:
	int w,h;
	byte orientation;
	char* ConvertDigitsNumber(int number);
};

const prog_uchar GREENBUTTON[] PROGMEM ={
		0x12, 0x12, 0x05, 0x02, 0x00,  
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0x08, 0xA5, 0x34, 0xCE, 0x79, 0xCE, 0x79, 0xCE, 0x79, 0xD6, 0xBA, 0xC6, 0x38, 0x9C, 0xF3, 0x42, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   // 0x0010 (16)
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x94, 0xB2, 0xCE, 0x79, 0xC6, 0x38, 0xA5, 0x34, 0x94, 0xB2, 0x8C, 0x71, 0x94, 0xB2, 0xAD, 0x75, 0xBD, 0xF7, 0xC6, 0x38,   // 0x0020 (32)
		0x8C, 0x71, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xAD, 0x75, 0xC6, 0x38, 0x9C, 0xF3, 0x73, 0xCE, 0x74, 0xEF, 0x85, 0xF1, 0x8E, 0xF2, 0x7D, 0xF0,   // 0x0030 (48)
		0x75, 0x2F, 0x84, 0xB0, 0xA5, 0x34, 0xBD, 0xF7, 0x9C, 0xF3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x94, 0xB2, 0xC6, 0x38, 0x8C, 0x71, 0x74, 0xAE, 0x8E, 0xB2, 0x9F, 0xB4,   // 0x0040 (64)
		0x8F, 0x72, 0x87, 0x71, 0x7F, 0x70, 0x77, 0x70, 0x6E, 0xAE, 0x85, 0x70, 0xA5, 0x34, 0xB5, 0xB6, 0x84, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0x08, 0xCE, 0x79, 0x9C, 0xF3, 0x74, 0xAE,   // 0x0050 (80)
		0x9F, 0x74, 0x8F, 0x72, 0x77, 0x70, 0x67, 0x6E, 0x5F, 0x6D, 0x5F, 0x6D, 0x5F, 0x6D, 0x5F, 0x6D, 0x4F, 0x2B, 0x85, 0xF1, 0xAD, 0x75, 0xAD, 0x75, 0x39, 0xC7, 0x00, 0x00, 0x00, 0x00, 0x9C, 0xF3,   // 0x0060 (96)
		0xBD, 0xF7, 0x7C, 0x2F, 0x86, 0xB1, 0x87, 0x72, 0x6F, 0x6F, 0x57, 0x2C, 0x4F, 0x2B, 0x47, 0x2B, 0x47, 0x2B, 0x4F, 0x2B, 0x4F, 0x2B, 0x47, 0x2A, 0x4E, 0x2B, 0xAD, 0xB5, 0xA5, 0x34, 0x73, 0x8E,   // 0x0070 (112)
		0x10, 0x82, 0x08, 0x41, 0xC6, 0x38, 0xA5, 0x34, 0x74, 0xEF, 0x87, 0x72, 0x6F, 0x6F, 0x57, 0x2C, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x3E, 0xE9, 0x35, 0xE8,   // 0x0080 (128)
		0x8D, 0xF1, 0xAD, 0x75, 0x84, 0x30, 0x21, 0x04, 0x10, 0x82, 0xC6, 0x38, 0x94, 0xB2, 0x76, 0x2F, 0x77, 0x70, 0x5F, 0x6D, 0x4F, 0x2B, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A,   // 0x0090 (144)
		0x47, 0x2A, 0x3E, 0xA9, 0x35, 0xA8, 0x5D, 0x6D, 0xB5, 0xB6, 0x84, 0x30, 0x31, 0x86, 0x18, 0xC3, 0xC6, 0x38, 0x94, 0xB2, 0x6E, 0xEE, 0x67, 0x6E, 0x4F, 0x2C, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A,   // 0x00A0 (160)
		0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x3E, 0x69, 0x2D, 0x27, 0x3C, 0xA8, 0xBD, 0xF7, 0x84, 0x30, 0x31, 0x86, 0x21, 0x04, 0xC6, 0x38, 0xA5, 0x34, 0x66, 0x6E, 0x57, 0x2C, 0x47, 0x2B,   // 0x00B0 (176)
		0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x3E, 0xEA, 0x35, 0xE8, 0x2C, 0x66, 0x5C, 0xAC, 0xBD, 0xF7, 0x84, 0x30, 0x39, 0xC7, 0x21, 0x04, 0xBD, 0xF7, 0xB5, 0xB6,   // 0x00C0 (192)
		0x7D, 0xF0, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x47, 0x2A, 0x3E, 0x69, 0x2D, 0x27, 0x23, 0x45, 0x8D, 0x71, 0xBD, 0xF7, 0x73, 0x8E, 0x42, 0x08,   // 0x00D0 (208)
		0x21, 0x04, 0x94, 0xB2, 0xB5, 0xB6, 0xA5, 0x74, 0x56, 0x6B, 0x3E, 0x69, 0x3E, 0xA9, 0x3E, 0xEA, 0x3E, 0xEA, 0x3E, 0xEA, 0x3E, 0xEA, 0x3E, 0x69, 0x35, 0x67, 0x23, 0x85, 0x43, 0x88, 0xB5, 0xF6,   // 0x00E0 (224)
		0x9C, 0xF3, 0x63, 0x0C, 0x4A, 0x49, 0x29, 0x45, 0x39, 0xC7, 0xB5, 0xB6, 0xB5, 0xB6, 0x95, 0xF2, 0x35, 0xA8, 0x35, 0x68, 0x35, 0xA8, 0x35, 0xE8, 0x35, 0xE8, 0x35, 0xA8, 0x2C, 0xA7, 0x23, 0x85,   // 0x00F0 (240)
		0x1A, 0xC4, 0x95, 0x72, 0xBD, 0xF7, 0x73, 0x8E, 0x63, 0x0C, 0x4A, 0x49, 0x21, 0x04, 0x00, 0x00, 0x73, 0x8E, 0xAD, 0x75, 0xBD, 0xF7, 0x95, 0xB2, 0x4C, 0xA9, 0x24, 0x26, 0x24, 0x26, 0x23, 0xC5,   // 0x0100 (256)
		0x23, 0x45, 0x1A, 0xC4, 0x3B, 0x48, 0x95, 0x72, 0xC6, 0x38, 0x84, 0x30, 0x63, 0x0C, 0x6B, 0x4D, 0x42, 0x08, 0x18, 0xC3, 0x00, 0x00, 0x08, 0x41, 0x7B, 0xCF, 0x9C, 0xF3, 0xBD, 0xF7, 0xB5, 0xF6,   // 0x0110 (272)
		0x8D, 0x71, 0x5C, 0x6B, 0x33, 0x47, 0x54, 0x2B, 0x8D, 0x31, 0xBE, 0x37, 0xBD, 0xF7, 0x84, 0x30, 0x5A, 0xCB, 0x73, 0x8E, 0x52, 0x8A, 0x29, 0x45, 0x08, 0x41, 0x08, 0x41, 0x10, 0x82, 0x18, 0xC3,   // 0x0120 (288)
		0x6B, 0x4D, 0x8C, 0x71, 0x9C, 0xF3, 0xB5, 0xB6, 0xBD, 0xF7, 0xC6, 0x38, 0xC6, 0x38, 0xBD, 0xF7, 0x9C, 0xF3, 0x73, 0x8E, 0x63, 0x0C, 0x7B, 0xCF, 0x5A, 0xCB, 0x31, 0x86, 0x10, 0x82, 0x00, 0x00,   // 0x0130 (304)
		0x00, 0x00, 0x08, 0x41, 0x18, 0xC3, 0x29, 0x45, 0x52, 0x8A, 0x63, 0x0C, 0x63, 0x0C, 0x6B, 0x4D, 0x6B, 0x4D, 0x6B, 0x4D, 0x63, 0x0C, 0x5A, 0xCB, 0x73, 0x8E, 0x7B, 0xCF, 0x5A, 0xCB, 0x31, 0x86,   // 0x0140 (320)
		0x10, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x82, 0x21, 0x04, 0x31, 0x86, 0x4A, 0x49, 0x63, 0x0C, 0x6B, 0x4D, 0x6B, 0x4D, 0x73, 0x8E, 0x73, 0x8E, 0x73, 0x8E, 0x63, 0x0C,   // 0x0150 (336)
		0x4A, 0x49, 0x29, 0x45, 0x10, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x41, 0x18, 0xC3, 0x29, 0x45, 0x31, 0x86, 0x39, 0xC7, 0x42, 0x08, 0x42, 0x08,   // 0x0160 (352)
		0x42, 0x08, 0x39, 0xC7, 0x29, 0x45, 0x18, 0xC3, 0x08, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x41, 0x08, 0x41,   // 0x0170 (368)
};

const prog_uchar REDBUTTON[] PROGMEM ={
		0x12, 0x12, 0x05, 0x02, 0x00, 
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0x08, 0xA5, 0x34, 0xCE, 0x79, 0xCE, 0x79, 0xCE, 0x79, 0xD6, 0xBA, 0xC6, 0x38, 0x9C, 0xF3, 0x42, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,   // 0x0010 (16)
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x94, 0xB2, 0xCE, 0x79, 0xC6, 0x38, 0xA5, 0x34, 0x94, 0xB2, 0x8C, 0x71, 0x94, 0xB2, 0xAD, 0x75, 0xBD, 0xF7, 0xC6, 0x38,   // 0x0020 (32)
		0x8C, 0x71, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xAD, 0x75, 0xC6, 0x38, 0x9C, 0xF3, 0x73, 0x4D, 0x93, 0x8E, 0xC3, 0xCF, 0xE3, 0xCF, 0xC3, 0x8E,   // 0x0030 (48)
		0x9B, 0x8E, 0x8B, 0xCF, 0xA5, 0x34, 0xBD, 0xF7, 0x9C, 0xF3, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x94, 0xB2, 0xC6, 0x38, 0x8C, 0x71, 0x8B, 0x8E, 0xDC, 0x30, 0xFC, 0x71,   // 0x0040 (64)
		0xFB, 0xCF, 0xFB, 0x4D, 0xFB, 0x0C, 0xFA, 0xCB, 0xE2, 0xCB, 0xA3, 0xCF, 0xA5, 0x34, 0xB5, 0xB6, 0x84, 0x30, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x42, 0x08, 0xCE, 0x79, 0x9C, 0xF3, 0x8B, 0x4D,   // 0x0050 (80)
		0xFC, 0x71, 0xFB, 0xCF, 0xFA, 0xCB, 0xFA, 0x49, 0xFA, 0x08, 0xF9, 0xC7, 0xFA, 0x08, 0xF9, 0xC7, 0xF9, 0x46, 0xAC, 0x30, 0xAD, 0x75, 0xAD, 0x75, 0x39, 0xC7, 0x00, 0x00, 0x00, 0x00, 0x9C, 0xF3,   // 0x0060 (96)
		0xBD, 0xF7, 0x7B, 0x8E, 0xDB, 0x8E, 0xFB, 0x4D, 0xFA, 0x8A, 0xF9, 0xC7, 0xF9, 0x45, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x45, 0xF9, 0x45, 0xF1, 0x04, 0xD1, 0xC7, 0xAD, 0x34, 0xA5, 0x34, 0x73, 0x8E,   // 0x0070 (112)
		0x10, 0x82, 0x08, 0x41, 0xC6, 0x38, 0xA5, 0x34, 0x9B, 0x8E, 0xFB, 0x4D, 0xFA, 0x8A, 0xF9, 0x86, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xE9, 0x04, 0xC8, 0xC3,   // 0x0080 (128)
		0xB4, 0x30, 0xAD, 0x75, 0x84, 0x30, 0x21, 0x04, 0x10, 0x82, 0xC6, 0x38, 0x94, 0xB2, 0xCB, 0x4D, 0xFA, 0xCB, 0xF9, 0xC7, 0xF9, 0x45, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04,   // 0x0090 (144)
		0xF9, 0x04, 0xE8, 0xC3, 0xC0, 0xC3, 0xB2, 0xCB, 0xB5, 0xB6, 0x84, 0x30, 0x31, 0x86, 0x18, 0xC3, 0xC6, 0x38, 0x94, 0xB2, 0xEA, 0x8A, 0xFA, 0x08, 0xF9, 0x86, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04,   // 0x00A0 (160)
		0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF1, 0x04, 0xD8, 0xC3, 0xB0, 0xC3, 0x99, 0x45, 0xBD, 0xF7, 0x84, 0x30, 0x31, 0x86, 0x21, 0x04, 0xC6, 0x38, 0xA5, 0x34, 0xD3, 0x0C, 0xF9, 0x86, 0xF9, 0x04,   // 0x00B0 (176)
		0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF1, 0x04, 0xC8, 0xC3, 0x90, 0x82, 0x9A, 0x8A, 0xBD, 0xF7, 0x84, 0x30, 0x39, 0xC7, 0x21, 0x04, 0xBD, 0xF7, 0xB5, 0xB6,   // 0x00C0 (192)
		0xB3, 0xCF, 0xF9, 0x04, 0xF1, 0x04, 0xF1, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF9, 0x04, 0xF1, 0x04, 0xD8, 0xC3, 0xB0, 0xC3, 0x78, 0x82, 0xA4, 0x30, 0xBD, 0xF7, 0x73, 0x8E, 0x42, 0x08,   // 0x00D0 (208)
		0x21, 0x04, 0x94, 0xB2, 0xB5, 0xB6, 0xA4, 0xB2, 0xD9, 0xC7, 0xD8, 0xC3, 0xE0, 0xC3, 0xE9, 0x04, 0xF1, 0x04, 0xF1, 0x04, 0xE9, 0x04, 0xD8, 0xC3, 0xB8, 0xC3, 0x80, 0x82, 0x79, 0x86, 0xBD, 0xB6,   // 0x00E0 (224)
		0x9C, 0xF3, 0x63, 0x0C, 0x4A, 0x49, 0x29, 0x45, 0x39, 0xC7, 0xB5, 0xB6, 0xB5, 0xB6, 0xB4, 0x71, 0xB8, 0xC3, 0xB8, 0xC3, 0xC0, 0xC3, 0xD0, 0xC3, 0xD0, 0xC3, 0xC0, 0xC3, 0xA0, 0x82, 0x78, 0x82,   // 0x00F0 (240)
		0x58, 0x82, 0xA4, 0x71, 0xBD, 0xF7, 0x73, 0x8E, 0x63, 0x0C, 0x4A, 0x49, 0x21, 0x04, 0x00, 0x00, 0x73, 0x8E, 0xAD, 0x75, 0xBD, 0xF7, 0xAC, 0x71, 0xA1, 0xC7, 0x88, 0x82, 0x88, 0x82, 0x88, 0x82,   // 0x0100 (256)
		0x78, 0x82, 0x60, 0x41, 0x71, 0x86, 0xA4, 0x71, 0xC6, 0x38, 0x84, 0x30, 0x63, 0x0C, 0x6B, 0x4D, 0x42, 0x08, 0x18, 0xC3, 0x00, 0x00, 0x08, 0x41, 0x7B, 0xCF, 0x9C, 0xF3, 0xBD, 0xF7, 0xB5, 0x75,   // 0x0110 (272)
		0xA4, 0x30, 0x92, 0x8A, 0x71, 0x45, 0x82, 0x8A, 0xA4, 0x30, 0xBD, 0xB6, 0xBD, 0xF7, 0x84, 0x30, 0x5A, 0xCB, 0x73, 0x8E, 0x52, 0x8A, 0x29, 0x45, 0x08, 0x41, 0x08, 0x41, 0x10, 0x82, 0x18, 0xC3,   // 0x0120 (288)
		0x6B, 0x4D, 0x8C, 0x71, 0x9C, 0xF3, 0xB5, 0xB6, 0xBD, 0xF7, 0xC6, 0x38, 0xC6, 0x38, 0xBD, 0xF7, 0x9C, 0xF3, 0x73, 0x8E, 0x63, 0x0C, 0x7B, 0xCF, 0x5A, 0xCB, 0x31, 0x86, 0x10, 0x82, 0x00, 0x00,   // 0x0130 (304)
		0x00, 0x00, 0x08, 0x41, 0x18, 0xC3, 0x29, 0x45, 0x52, 0x8A, 0x63, 0x0C, 0x63, 0x0C, 0x6B, 0x4D, 0x6B, 0x4D, 0x6B, 0x4D, 0x63, 0x0C, 0x5A, 0xCB, 0x73, 0x8E, 0x7B, 0xCF, 0x5A, 0xCB, 0x31, 0x86,   // 0x0140 (320)
		0x10, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x82, 0x21, 0x04, 0x31, 0x86, 0x4A, 0x49, 0x63, 0x0C, 0x6B, 0x4D, 0x6B, 0x4D, 0x73, 0x8E, 0x73, 0x8E, 0x73, 0x8E, 0x63, 0x0C,   // 0x0150 (336)
		0x4A, 0x49, 0x29, 0x45, 0x10, 0x82, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x41, 0x18, 0xC3, 0x29, 0x45, 0x31, 0x86, 0x39, 0xC7, 0x42, 0x08, 0x42, 0x08,   // 0x0160 (352)
		0x42, 0x08, 0x39, 0xC7, 0x29, 0x45, 0x18, 0xC3, 0x08, 0x41, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x41, 0x08, 0x41,   // 0x0170 (368)
};

const prog_uchar ICONLOGO[] PROGMEM ={
		0x18, 0x18, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5E, 0xCE, 0x7D, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x9E, 
		0xCE, 0x9E, 0xCE, 0x9E, 0xCE, 0x7D, 0xDE, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xAD, 0xBC, 0x4A, 0xB9, 0x63, 0x7A, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 
		0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x63, 0x9B, 0x4A, 0xDA, 0x8C, 0xDB, 0xFF, 0xFF, 0xE7, 0x3E, 0x4A, 0xB9, 0xA5, 0x5C, 0xB5, 0xDD, 0xB5, 0xDD, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 
		0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDE, 0xB5, 0xDD, 0xB5, 0xDD, 0xAD, 0xBD, 0x4A, 0xDA, 0xC6, 0x5D, 0xCE, 0x7D, 0x53, 0x3A, 0xAD, 0x9D, 0x9D, 0x5D, 
		0x9D, 0x7D, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7E, 0x9D, 0x7D, 0x9D, 0x5D, 0xAD, 0x9D, 0x63, 0x9A, 
		0xA5, 0x7C, 0xCE, 0x9E, 0x53, 0x3A, 0x9D, 0x3D, 0x95, 0x1D, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 0x95, 0x3E, 
		0x95, 0x3E, 0x95, 0x3E, 0x95, 0x1D, 0x9D, 0x5D, 0x5B, 0x7B, 0xA5, 0x7C, 0xCE, 0x9E, 0x4B, 0x1A, 0x8C, 0xFD, 0x8C, 0xFD, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 
		0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8C, 0xFE, 0x8D, 0x1D, 0x53, 0x3B, 0xA5, 0x7C, 0xCE, 0x9E, 0x4A, 0xDA, 0x84, 0xBD, 0x7C, 0x9D, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0xBE, 
		0x7C, 0xDE, 0x7C, 0xDE, 0x7C, 0xDE, 0x7C, 0xDE, 0x7C, 0xDE, 0x7C, 0xDE, 0x7C, 0xDE, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0xBE, 0x7C, 0x9D, 0x84, 0xBD, 0x4B, 0x1B, 0xA5, 0x7C, 0xCE, 0x9E, 0x42, 0xBA, 0x7C, 0x7D, 0x74, 0x5D, 
		0x74, 0x7E, 0x74, 0x7E, 0x74, 0x7E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x9E, 0x74, 0x7E, 0x74, 0x7E, 0x74, 0x7E, 0x74, 0x5D, 0x7C, 0x7D, 0x42, 0xDA, 
		0xA5, 0x9C, 0xCE, 0x9E, 0x3A, 0x9A, 0x6C, 0x1C, 0x6C, 0x1D, 0x6C, 0x3E, 0x6C, 0x3E, 0x6C, 0x5E, 0x6C, 0x5E, 0x6C, 0x5E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x7E, 0x6C, 0x5E, 0x6C, 0x5E, 
		0x6C, 0x5E, 0x6C, 0x3E, 0x6C, 0x1D, 0x6C, 0x1D, 0x3A, 0xBA, 0xAD, 0x9C, 0xCE, 0xBE, 0x3A, 0x7A, 0x63, 0xDC, 0x5B, 0xDD, 0x5B, 0xFE, 0x5C, 0x1E, 0x5C, 0x3E, 0x5C, 0x3E, 0x5C, 0x3E, 0x5C, 0x5E, 0x5C, 0x5E, 0x5C, 0x5E, 0x5C, 0x5E, 0x5C, 0x5E, 
		0x5C, 0x5E, 0x5C, 0x5E, 0x5C, 0x5E, 0x5C, 0x3E, 0x5C, 0x3E, 0x5C, 0x1E, 0x5B, 0xFE, 0x5B, 0xFD, 0x63, 0xDD, 0x32, 0x7A, 0xAD, 0x9C, 0xCE, 0xBE, 0x32, 0x5A, 0x53, 0x7C, 0x4B, 0x7D, 0x4B, 0xBD, 0x4B, 0xBE, 0x4B, 0xDE, 0x4B, 0xDE, 0x4B, 0xFE, 
		0x4C, 0x1E, 0x54, 0x3E, 0x54, 0x3E, 0x54, 0x5E, 0x54, 0x5E, 0x54, 0x3E, 0x4C, 0x1E, 0x4B, 0xFE, 0x4B, 0xFE, 0x4B, 0xDE, 0x4B, 0xDE, 0x4B, 0xBE, 0x4B, 0x9D, 0x53, 0x9C, 0x32, 0x5A, 0xAD, 0x9C, 0xCE, 0xBE, 0x21, 0xFA, 0x6C, 0x1C, 0x7C, 0xDD, 
		0x85, 0x1E, 0x8D, 0x5E, 0x8D, 0x7E, 0x95, 0x9E, 0x8D, 0x7E, 0x64, 0xDE, 0x44, 0x1E, 0x44, 0x1E, 0x4C, 0x5E, 0x44, 0x1E, 0x44, 0x1E, 0x5C, 0x9E, 0x85, 0x5E, 0x95, 0x9E, 0x8D, 0x7E, 0x8D, 0x5E, 0x85, 0x3E, 0x7C, 0xFE, 0x74, 0x7D, 0x29, 0xFA, 
		0xA5, 0x9C, 0xD6, 0xDE, 0x9, 0x19, 0x11, 0xFB, 0x43, 0x7D, 0x8D, 0x5E, 0xB6, 0x5E, 0xC6, 0xDF, 0xD7, 0x1F, 0xEF, 0x9F, 0xF7, 0xDF, 0xCF, 0x1F, 0x6D, 0x3E, 0x33, 0xFE, 0x5C, 0xDE, 0xBE, 0xBF, 0xF7, 0xBF, 0xEF, 0xBF, 0xD7, 0x3F, 0xCE, 0xFF, 
		0xB6, 0x7F, 0x9D, 0xBE, 0x4B, 0xDD, 0x1A, 0x3B, 0x0, 0xD9, 0xAD, 0x9C, 0xD6, 0xDE, 0x9, 0x39, 0x1, 0x9B, 0x1, 0xFC, 0x2, 0x7D, 0x13, 0x1E, 0x33, 0xDE, 0x64, 0xFE, 0x7D, 0x7E, 0xA6, 0x5E, 0xE7, 0x7F, 0xFF, 0xFF, 0xAE, 0x7F, 0xF7, 0xBF, 
		0xEF, 0xBF, 0xAE, 0x7E, 0x85, 0x9E, 0x6D, 0x1E, 0x3C, 0x1E, 0x13, 0x1E, 0x2, 0x9D, 0x2, 0x1D, 0x1, 0xBB, 0x0, 0xD9, 0xAD, 0xBC, 0xD6, 0xDE, 0x9, 0x38, 0x1, 0xBB, 0x2, 0x7C, 0x2, 0xBD, 0x2, 0xFE, 0x3, 0x1E, 0xB, 0x7E, 0x2C, 0x3E, 
		0x4C, 0xDE, 0x7D, 0x9E, 0xC7, 0x1F, 0xEF, 0xBF, 0xD7, 0x5F, 0x85, 0xDE, 0x54, 0xFE, 0x34, 0x5E, 0xB, 0x9E, 0x3, 0x1E, 0x2, 0xFE, 0x2, 0xDD, 0x2, 0x9D, 0x1, 0xFB, 0x0, 0xD8, 0xAD, 0x9C, 0xD6, 0xDE, 0x9, 0x38, 0x1, 0xDB, 0x2, 0x9C, 
		0x2, 0xFD, 0x3, 0x3E, 0x3, 0x7E, 0x3, 0x9E, 0x3, 0xDE, 0x3, 0xFE, 0x14, 0x3E, 0x24, 0x9E, 0x14, 0x7E, 0x24, 0x9E, 0x14, 0x5E, 0xC, 0x1E, 0x3, 0xDE, 0x3, 0xBE, 0x3, 0x7E, 0x3, 0x5E, 0x3, 0x1E, 0x2, 0xBD, 0x2, 0x1B, 0x0, 0xF8, 
		0xAD, 0x9C, 0xD6, 0xDE, 0x9, 0x58, 0x1, 0xFB, 0x2, 0xDD, 0x3, 0x3D, 0x3, 0x7E, 0x3, 0xBE, 0x3, 0xDE, 0x4, 0x1E, 0x4, 0x3E, 0x4, 0x3E, 0x4, 0x5E, 0x4, 0x5E, 0x4, 0x5E, 0x4, 0x5E, 0x4, 0x3E, 0x4, 0x1E, 0x3, 0xFE, 0x3, 0xDE, 
		0x3, 0x9E, 0x3, 0x5E, 0x2, 0xFD, 0x2, 0x3B, 0x0, 0xF8, 0xAD, 0x9C, 0xD6, 0xDE, 0x9, 0x58, 0x2, 0x1B, 0x2, 0xFD, 0x3, 0x7E, 0x3, 0xBE, 0x3, 0xFE, 0x4, 0x3E, 0x4, 0x5E, 0x4, 0x7E, 0x4, 0x9E, 0x4, 0xBE, 0x4, 0xBE, 0x4, 0xBE, 
		0x4, 0xBE, 0x4, 0x9E, 0x4, 0x7E, 0x4, 0x3E, 0x4, 0x1E, 0x3, 0xDE, 0x3, 0x9E, 0x3, 0x3D, 0x2, 0x5B, 0x0, 0xF8, 0xAD, 0x9C, 0xD6, 0xDE, 0x9, 0x58, 0x2, 0x3B, 0x3, 0x3D, 0x3, 0x9E, 0x3, 0xFE, 0x4, 0x3E, 0x4, 0x7E, 0x4, 0x9E, 
		0x4, 0xDE, 0x4, 0xFE, 0x4, 0xFE, 0x5, 0x1E, 0x4, 0xFE, 0x4, 0xFE, 0x4, 0xDE, 0x4, 0xBE, 0x4, 0x7E, 0x4, 0x3E, 0x3, 0xFE, 0x3, 0xBE, 0x3, 0x5D, 0x2, 0x7B, 0x0, 0xF8, 0xAD, 0x9C, 0xD6, 0xDE, 0x9, 0x58, 0x2, 0x3A, 0x3, 0x5D, 
		0x3, 0xBE, 0x4, 0x1E, 0x4, 0x5E, 0x4, 0x9E, 0x4, 0xDE, 0x5, 0x1E, 0x5, 0x1E, 0x5, 0x3E, 0x5, 0x3E, 0x5, 0x3E, 0x5, 0x3E, 0x5, 0x1E, 0x4, 0xFE, 0x4, 0xBE, 0x4, 0x7E, 0x4, 0x3E, 0x3, 0xDE, 0x3, 0x7D, 0x2, 0x9B, 0x0, 0xF8, 
		0xAD, 0x9D, 0xD6, 0xBE, 0x9, 0x37, 0x2, 0x3A, 0x3, 0x5D, 0x3, 0xDD, 0x4, 0x3E, 0x4, 0x9E, 0x4, 0xDE, 0x5, 0x1E, 0x5, 0x3E, 0x5, 0x5E, 0x5, 0x7E, 0x5, 0x7E, 0x5, 0x7E, 0x5, 0x7E, 0x5, 0x5E, 0x5, 0x1E, 0x4, 0xDE, 0x4, 0x9E, 
		0x4, 0x5E, 0x3, 0xFD, 0x3, 0x9D, 0x2, 0x9B, 0x0, 0xF7, 0xAD, 0x9C, 0xD6, 0xBE, 0x9, 0x17, 0x2, 0x19, 0x3, 0x5C, 0x3, 0xFD, 0x4, 0x3D, 0x4, 0x9E, 0x4, 0xDE, 0x5, 0x1E, 0x5, 0x5E, 0x5, 0x7E, 0x5, 0x9E, 0x5, 0xBE, 0x5, 0xBE, 
		0x5, 0x9E, 0x5, 0x5E, 0x5, 0x3E, 0x4, 0xFE, 0x4, 0xBE, 0x4, 0x5D, 0x4, 0x1D, 0x3, 0x9D, 0x2, 0x7A, 0x0, 0xD6, 0xAD, 0x9C, 0xE7, 0x5E, 0x11, 0x37, 0x1, 0x55, 0xA, 0x78, 0x2, 0xFA, 0x3, 0x3A, 0x3, 0x7A, 0x3, 0xBA, 0x3, 0xDB, 
		0xC, 0x1B, 0xC, 0x3B, 0x4, 0x3B, 0xC, 0x5B, 0x4, 0x5B, 0x4, 0x3B, 0x4, 0x1B, 0x3, 0xFB, 0x3, 0xBB, 0x3, 0x9A, 0x3, 0x5A, 0x3, 0x1A, 0xA, 0x99, 0x9, 0xB6, 0x0, 0xB6, 0xC6, 0x5D, 0xFF, 0xFF, 0x95, 0x1C, 0x8, 0xF6, 0x0, 0xD5, 
		0x1, 0x16, 0x1, 0x36, 0x1, 0x56, 0x1, 0x56, 0x1, 0x56, 0x1, 0x56, 0x1, 0x76, 0x1, 0x76, 0x1, 0x76, 0x1, 0x76, 0x1, 0x76, 0x1, 0x76, 0x1, 0x56, 0x1, 0x56, 0x1, 0x56, 0x1, 0x36, 0x1, 0x16, 0x0, 0xF5, 0x0, 0xD6, 0x6B, 0xFB, 
		0xFF, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD6, 0xDE, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1E, 0xBE, 0x1E, 0xBE, 0x1E, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1E, 0xBE, 0x1E, 0xBE, 0x1E, 
		0xBE, 0x1D, 0xBE, 0x1D, 0xBE, 0x1D, 0xCE, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF};

const prog_uchar ARROWRIGHT[] PROGMEM ={
		0x16, 0x16, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0xBD, 0xFA, 0xA5, 0x39, 0x8C, 0xD7, 0xA5, 0x39, 0xBD, 0xFA, 0xE7, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0x5A, 0x74, 0x16, 0x74, 0x16, 0x8D, 0x3A, 0xA5, 0xDC, 0xAE, 0x1D, 0xA5, 0xDC, 0x8D, 0x3A, 0x74, 0x16, 0x74, 0x16, 
		0xC6, 0x5A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7E, 0x74, 0x16, 0x74, 0x99, 0xB6, 0x9F, 0xC6, 0xDF, 0xC6, 0xDF, 0xC6, 0xDF, 0xC6, 0xDF, 0xC6, 0xDF, 
		0xC6, 0xDF, 0xC6, 0xDF, 0xB6, 0x9F, 0x74, 0x99, 0x74, 0x16, 0xEF, 0x7E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF, 0x1D, 0x5B, 0x95, 0x95, 0xBF, 0xB6, 0x9F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 
		0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xB6, 0x9F, 0x95, 0xBF, 0x5B, 0x95, 0xDF, 0x1D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7E, 0x5B, 0x95, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0x7F, 
		0x95, 0xBF, 0x95, 0x7F, 0x95, 0x7F, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x5B, 0x95, 0xEF, 0x7E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x16, 0x7D, 0x7E, 
		0x85, 0x3F, 0x7D, 0x1E, 0x7D, 0x1E, 0x7D, 0x1E, 0xA5, 0xDC, 0xAD, 0xFC, 0x7D, 0x1E, 0x7D, 0x1E, 0x85, 0x3F, 0x85, 0x3F, 0x85, 0x3F, 0x85, 0x3F, 0x85, 0x3F, 0x7D, 0x1E, 0x85, 0x3F, 0x7D, 0x1E, 0x74, 0x16, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xC6, 0x5A, 0x54, 0x39, 0x74, 0xDD, 0x64, 0x5C, 0x6C, 0x9D, 0x6C, 0x9D, 0x64, 0x5C, 0xC6, 0x5A, 0xF7, 0x9D, 0xBE, 0x9C, 0x74, 0xDD, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x74, 0xDD, 0x53, 0xDA, 
		0xC6, 0x5A, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x16, 0x6C, 0x9D, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0xC6, 0x5A, 0xEF, 0x5C, 0xF7, 0x9D, 0xDF, 0x1D, 0x74, 0x99, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 
		0x53, 0xDA, 0x53, 0xDA, 0x64, 0x5C, 0x74, 0x16, 0xFF, 0xFF, 0xEF, 0x5C, 0x43, 0xB9, 0x43, 0xB9, 0x32, 0xF6, 0x3B, 0x17, 0x43, 0x57, 0x43, 0x57, 0x43, 0x57, 0xC6, 0x5A, 0xEF, 0x5C, 0xEF, 0x5C, 0xF7, 0xBE, 0xEF, 0x7E, 0x8D, 0x3A, 0x43, 0x57, 
		0x43, 0x57, 0x43, 0x57, 0x43, 0x57, 0x43, 0x57, 0x3B, 0x17, 0x43, 0x57, 0x43, 0x57, 0xE7, 0x5D, 0xBE, 0x1A, 0x43, 0xB9, 0x22, 0x94, 0x22, 0x54, 0x22, 0x54, 0x2A, 0x94, 0x2A, 0x94, 0x2A, 0x94, 0xBE, 0x1A, 0xEF, 0x5C, 0xEF, 0x5C, 0xEF, 0x7E, 
		0xF7, 0xBE, 0xFF, 0xFF, 0xAD, 0x99, 0x32, 0xF6, 0x2A, 0x94, 0x2A, 0x94, 0x2A, 0x94, 0x22, 0x54, 0x22, 0x54, 0x3B, 0x17, 0xBE, 0x1A, 0xAD, 0x99, 0x33, 0x79, 0x19, 0xF2, 0x19, 0xF2, 0x22, 0x33, 0x22, 0x33, 0x22, 0x33, 0x22, 0x33, 0xBE, 0x1A, 
		0xEF, 0x5C, 0xEF, 0x5C, 0xEF, 0x7E, 0xF7, 0xBE, 0xFF, 0xFF, 0xFF, 0xFF, 0xBE, 0x9C, 0x3A, 0xF5, 0x22, 0x33, 0x22, 0x33, 0x19, 0xF2, 0x19, 0xF2, 0x22, 0xD6, 0xA5, 0x39, 0xA5, 0x39, 0x2A, 0x94, 0x0, 0xAA, 0x1, 0xE, 0x11, 0x90, 0x11, 0xD2, 
		0x19, 0xF2, 0x19, 0xF2, 0xBE, 0x1A, 0xEF, 0x5C, 0xEF, 0x5C, 0xEF, 0x7E, 0xF7, 0xBE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x8C, 0xD7, 0x11, 0xD2, 0x19, 0xF2, 0x11, 0xD2, 0x11, 0x90, 0x22, 0x94, 0xA5, 0x39, 0xAD, 0x99, 0x2A, 0x94, 0x0, 0x87, 
		0x0, 0x87, 0x0, 0x87, 0x0, 0xAA, 0x9, 0xC, 0x1, 0xE, 0xBD, 0xF9, 0xEF, 0x5C, 0xEF, 0x5C, 0xEF, 0x7E, 0xF7, 0xBE, 0xFF, 0xFF, 0xFF, 0xFF, 0xAD, 0x99, 0x21, 0xEF, 0x1, 0xE, 0x9, 0xC, 0x0, 0xAA, 0x0, 0x87, 0x21, 0xEF, 0xA5, 0x39, 
		0xBE, 0x1A, 0x32, 0xF6, 0x0, 0xAA, 0x0, 0x87, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0xBD, 0xF9, 0xEF, 0x5C, 0xEF, 0x5C, 0xEF, 0x7E, 0xFF, 0xFF, 0xF7, 0xBE, 0x74, 0x16, 0x9, 0xC, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0x87, 
		0x0, 0x87, 0x2A, 0x71, 0xBE, 0x1A, 0xE7, 0x5D, 0x43, 0x57, 0x11, 0x90, 0x0, 0x87, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xEC, 0x0, 0xEC, 0xBD, 0xF9, 0xEF, 0x5C, 0xEF, 0x5C, 0xF7, 0xBE, 0xEF, 0x5C, 0x5B, 0x95, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xEC, 
		0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x9, 0xC, 0x32, 0xF6, 0xE7, 0x5D, 0xFF, 0xFF, 0x74, 0x99, 0x2A, 0x94, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xEC, 0xBD, 0xF9, 0xEF, 0x5C, 0xF7, 0x9D, 0xC6, 0x5A, 0x2A, 0x71, 0x0, 0xEC, 
		0x0, 0xEC, 0x1, 0xE, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xAA, 0x19, 0xF2, 0x74, 0x16, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0x5A, 0x33, 0x79, 0x11, 0x90, 0x0, 0xEC, 0x0, 0xEC, 0x1, 0xE, 0x1, 0xE, 0xC6, 0x5A, 0xF7, 0x9D, 0xA5, 0x36, 
		0x11, 0x90, 0x1, 0xE, 0x1, 0x50, 0x1, 0x50, 0x1, 0xE, 0x1, 0xE, 0x0, 0xEC, 0x0, 0xEC, 0x1, 0xE, 0x22, 0xD6, 0xC6, 0x5A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x99, 0x33, 0x79, 0x1, 0xE, 0x0, 0xEC, 0x1, 0xE, 0x1, 0x50, 
		0x74, 0x16, 0x74, 0x16, 0x11, 0x90, 0x1, 0x50, 0x1, 0x50, 0x1, 0x50, 0x1, 0x50, 0x1, 0x50, 0x1, 0xE, 0x1, 0xE, 0x1, 0xE, 0x22, 0xD6, 0x74, 0x99, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0x54, 0x39, 0x33, 0x79, 
		0x1, 0x50, 0x1, 0xE, 0x1, 0x50, 0x1, 0x50, 0x11, 0x90, 0x22, 0x33, 0x22, 0x54, 0x22, 0x54, 0x19, 0xF2, 0x11, 0x90, 0x1, 0x50, 0x1, 0xE, 0x1, 0x50, 0x22, 0xD6, 0x54, 0x39, 0xE7, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xDF, 0x1D, 0x54, 0x39, 0x33, 0x79, 0x11, 0xD2, 0x1, 0x50, 0x19, 0xF2, 0x2A, 0x94, 0x3B, 0x17, 0x43, 0x57, 0x43, 0x57, 0x32, 0xF6, 0x22, 0x33, 0x11, 0x90, 0x11, 0xD2, 0x33, 0x79, 0x54, 0x39, 0xDF, 0x1D, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0x6D, 0x19, 0x43, 0xB9, 0x33, 0x79, 0x43, 0x57, 0x53, 0xDA, 0x64, 0x5C, 0x64, 0x5C, 0x64, 0x5C, 0x53, 0xDA, 0x43, 0xB9, 0x33, 0x79, 0x33, 0x79, 0x6D, 0x19, 0xE7, 0x5D, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xBE, 0x9C, 0x6D, 0x19, 0x54, 0xBB, 0x65, 0x3D, 0x7D, 0x7E, 0x85, 0xDF, 0x7D, 0x7E, 0x65, 0x3D, 0x54, 0xBB, 0x6D, 0x19, 
		0xBE, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0xBE, 0x9C, 0x9E, 0x1B, 0x9E, 0x1B, 0x9E, 0x1B, 
		0xBE, 0x9C, 0xE7, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};

const prog_uchar ARROWLEFT[] PROGMEM ={
		0x16, 0x16, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0xBD, 0xFA, 0xA5, 0x39, 0x8C, 0xD7, 0xA5, 0x39, 0xBD, 0xFA, 0xE7, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0x5A, 0x74, 0x16, 0x74, 0x16, 0x8D, 0x3A, 0xA5, 0xDC, 0xAE, 0x1D, 0xA5, 0xDC, 0x8D, 0x3A, 0x74, 0x16, 0x74, 0x16, 
		0xC6, 0x5A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7E, 0x74, 0x16, 0x74, 0x99, 0xB6, 0x9F, 0xC6, 0xDF, 0xC6, 0xDF, 0xC6, 0xDF, 0xC6, 0xDF, 0xC6, 0xDF, 
		0xC6, 0xDF, 0xC6, 0xDF, 0xB6, 0x9F, 0x74, 0x99, 0x74, 0x16, 0xEF, 0x7E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF, 0x1D, 0x5B, 0x95, 0x95, 0xBF, 0xB6, 0x9F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 
		0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xAE, 0x1F, 0xB6, 0x9F, 0x95, 0xBF, 0x5B, 0x95, 0xDF, 0x1D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7E, 0x5B, 0x95, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 
		0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0xBF, 0x95, 0x7F, 0x95, 0x7F, 0x95, 0xBF, 0x95, 0x7F, 0x95, 0xBF, 0x95, 0xBF, 0x5B, 0x95, 0xEF, 0x7E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x16, 0x7D, 0x1E, 
		0x85, 0x3F, 0x7D, 0x1E, 0x85, 0x3F, 0x85, 0x3F, 0x85, 0x3F, 0x85, 0x3F, 0x85, 0x3F, 0x7D, 0x1E, 0x7D, 0x1E, 0xAD, 0xFC, 0xA5, 0xDC, 0x7D, 0x1E, 0x7D, 0x1E, 0x7D, 0x1E, 0x85, 0x3F, 0x7D, 0x7E, 0x74, 0x16, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xC6, 0x5A, 0x53, 0xDA, 0x74, 0xDD, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x6C, 0x9D, 0x74, 0xDD, 0xBE, 0x9C, 0xF7, 0x9D, 0xC6, 0x5A, 0x64, 0x5C, 0x6C, 0x9D, 0x6C, 0x9D, 0x64, 0x5C, 0x74, 0xDD, 0x54, 0x39, 
		0xC6, 0x5A, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x16, 0x64, 0x5C, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 0x74, 0x99, 0xDF, 0x1D, 0xF7, 0x9D, 0xEF, 0x5C, 0xC6, 0x5A, 0x53, 0xDA, 0x53, 0xDA, 0x53, 0xDA, 
		0x53, 0xDA, 0x53, 0xDA, 0x54, 0xBB, 0x74, 0x16, 0xFF, 0xFF, 0xE7, 0x5D, 0x43, 0x57, 0x43, 0x57, 0x3B, 0x17, 0x43, 0x57, 0x43, 0x57, 0x43, 0x57, 0x43, 0x57, 0x3B, 0x17, 0x8D, 0x3A, 0xEF, 0x7E, 0xF7, 0xBE, 0xEF, 0x5C, 0xEF, 0x5C, 0xC6, 0x5A, 
		0x43, 0x57, 0x43, 0x57, 0x43, 0x57, 0x3B, 0x17, 0x32, 0xF6, 0x43, 0xB9, 0x43, 0xB9, 0xE7, 0x5D, 0xBE, 0x1A, 0x3B, 0x17, 0x22, 0x54, 0x22, 0x54, 0x2A, 0x94, 0x2A, 0x94, 0x2A, 0x94, 0x32, 0xF6, 0xAD, 0x99, 0xFF, 0xFF, 0xF7, 0xBE, 0xEF, 0x7E, 
		0xEF, 0x5C, 0xEF, 0x5C, 0xBE, 0x1A, 0x2A, 0x94, 0x2A, 0x94, 0x2A, 0x94, 0x22, 0x54, 0x22, 0x54, 0x22, 0x54, 0x33, 0x79, 0xBE, 0x1A, 0xA5, 0x39, 0x22, 0xD6, 0x19, 0xF2, 0x19, 0xF2, 0x22, 0x33, 0x22, 0x33, 0x3A, 0xF5, 0xBE, 0x9C, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xF7, 0xBE, 0xEF, 0x7E, 0xEF, 0x5C, 0xEF, 0x5C, 0xBE, 0x1A, 0x22, 0x33, 0x22, 0x33, 0x22, 0x33, 0x22, 0x33, 0x19, 0xF2, 0x19, 0xF2, 0x33, 0x79, 0xAD, 0x99, 0xA5, 0x39, 0x22, 0x94, 0x11, 0x90, 0x11, 0xD2, 0x19, 0xF2, 0x11, 0xD2, 
		0x8C, 0xD7, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBE, 0xEF, 0x7E, 0xEF, 0x5C, 0xEF, 0x5C, 0xBE, 0x1A, 0x19, 0xF2, 0x19, 0xF2, 0x11, 0xD2, 0x11, 0x90, 0x1, 0xE, 0x0, 0xAA, 0x2A, 0x94, 0xA5, 0x39, 0xA5, 0x39, 0x21, 0xEF, 0x0, 0x87, 
		0x0, 0xAA, 0x9, 0xC, 0x1, 0xE, 0x21, 0xEF, 0xAD, 0x99, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBE, 0xEF, 0x7E, 0xEF, 0x5C, 0xEF, 0x5C, 0xBD, 0xF9, 0x1, 0xE, 0x9, 0xC, 0x0, 0xAA, 0x0, 0x87, 0x0, 0x87, 0x0, 0x87, 0x2A, 0x94, 0xAD, 0x99, 
		0xBE, 0x1A, 0x22, 0x54, 0x0, 0x87, 0x0, 0x87, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x9, 0xC, 0x74, 0x16, 0xF7, 0xBE, 0xFF, 0xFF, 0xEF, 0x7E, 0xEF, 0x5C, 0xEF, 0x5C, 0xBD, 0xF9, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0x87, 
		0x0, 0xAA, 0x32, 0xF6, 0xBE, 0x1A, 0xE7, 0x5D, 0x3A, 0xF5, 0x9, 0xC, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xAA, 0x5B, 0x95, 0xEF, 0x5C, 0xF7, 0xBE, 0xEF, 0x5C, 0xEF, 0x5C, 0xBD, 0xF9, 0x0, 0xEC, 0x0, 0xEC, 
		0x0, 0xAA, 0x0, 0xAA, 0x0, 0x87, 0x11, 0x90, 0x43, 0x57, 0xE7, 0x5D, 0xFF, 0xFF, 0x74, 0x16, 0x19, 0xF2, 0x0, 0xAA, 0x0, 0xAA, 0x0, 0xEC, 0x0, 0xEC, 0x1, 0xE, 0x1, 0xE, 0x0, 0xEC, 0x2A, 0x71, 0xC6, 0x5A, 0xF7, 0x9D, 0xEF, 0x5C, 
		0xBD, 0xF9, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xEC, 0x0, 0xAA, 0x0, 0xAA, 0x2A, 0x94, 0x74, 0x99, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0x5A, 0x22, 0xD6, 0x1, 0xE, 0x0, 0xEC, 0x0, 0xEC, 0x1, 0xE, 0x1, 0xE, 0x1, 0x50, 0x1, 0x50, 0x1, 0xE, 
		0x11, 0x90, 0xA5, 0x36, 0xF7, 0x9D, 0xC6, 0x5A, 0x1, 0xE, 0x1, 0xE, 0x0, 0xEC, 0x0, 0xAA, 0x11, 0x90, 0x33, 0x79, 0xC6, 0x5A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x99, 0x22, 0xD6, 0x1, 0xE, 0x1, 0xE, 0x1, 0xE, 0x1, 0x50, 
		0x1, 0x50, 0x1, 0x50, 0x1, 0x50, 0x1, 0x50, 0x11, 0x90, 0x74, 0x16, 0x74, 0x16, 0x1, 0xE, 0x1, 0xE, 0x0, 0xEC, 0x1, 0xE, 0x33, 0x79, 0x74, 0x99, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0x54, 0x39, 0x22, 0xD6, 
		0x1, 0x50, 0x1, 0xE, 0x1, 0x50, 0x11, 0x90, 0x19, 0xF2, 0x22, 0x54, 0x22, 0x54, 0x22, 0x33, 0x11, 0x90, 0x1, 0x50, 0x1, 0x50, 0x1, 0xE, 0x1, 0x50, 0x33, 0x79, 0x54, 0x39, 0xE7, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xDF, 0x1D, 0x54, 0x39, 0x33, 0x79, 0x11, 0xD2, 0x11, 0x90, 0x22, 0x33, 0x32, 0xF6, 0x43, 0x57, 0x43, 0x57, 0x3B, 0x17, 0x2A, 0x94, 0x19, 0xF2, 0x1, 0x50, 0x11, 0xD2, 0x33, 0x79, 0x54, 0x39, 0xDF, 0x1D, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0x6D, 0x19, 0x33, 0x79, 0x33, 0x79, 0x43, 0xB9, 0x53, 0xDA, 0x64, 0x5C, 0x64, 0x5C, 0x64, 0x5C, 0x53, 0xDA, 0x43, 0x57, 0x33, 0x79, 0x43, 0xB9, 0x6D, 0x19, 0xE7, 0x5D, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xBE, 0x9C, 0x6D, 0x19, 0x54, 0xBB, 0x65, 0x3D, 0x7D, 0x7E, 0x85, 0xDF, 0x7D, 0x7E, 0x65, 0x3D, 0x54, 0xBB, 0x6D, 0x19, 
		0xBE, 0x9C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5D, 0xBE, 0x9C, 0x9E, 0x1B, 0x9E, 0x1B, 0x9E, 0x1B, 
		0xBE, 0x9C, 0xE7, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};

const prog_uchar DIVIDER[] PROGMEM ={
		0x3, 0x15, 0x05, 0x02, 0x00, 
		0x5A, 0xCB, 0x5A, 0xCB, 0xEF, 0x5D, 0xF7, 0xBE, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 0xEF, 0x5D, 0x5A, 0xCB, 0x5A, 0xCB, 0xD6, 0xDA, 0xF7, 0x9E, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 
		0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 0xEF, 0x5D, 0x5A, 0xCB, 0x5A, 0xCB, 0xD6, 0xDA, 0xF7, 0x9E, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 0xEF, 0x5D, 0x5A, 0xCB, 0x5A, 0xCB, 0xD6, 0xDA, 
		0xF7, 0x9E, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 0xEF, 0x5D, 0x5A, 0xCB, 0x5A, 0xCB, 0xD6, 0xDA, 0xF7, 0x9E, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 
		0xEF, 0x5D, 0x5A, 0xCB, 0x5A, 0xCB, 0xD6, 0xDA, 0xF7, 0x9E, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 0xEF, 0x5D, 0x5A, 0xCB, 0x5A, 0xCB, 0xD6, 0xDA, 0xF7, 0x9E, 0x5A, 0xCB, 0x5A, 0xCB, 0xC6, 0x38, 
		0xEF, 0x5D, 0xEF, 0x5D, 0xC6, 0x38, 0xC6, 0x38, 0xEF, 0x5D, 0xF7, 0xBE, 0xEF, 0x5D, 0xEF, 0x5D, 0xF7, 0xBE};

const prog_uchar ARROWMENU[] PROGMEM ={
		0x6, 0x4, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFD, 0x20, 0xEF, 0x7D, 0xF7, 0xBE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFD, 0x20, 0xFD, 0x20, 0xFD, 0x20, 0xD6, 0xDA, 0xF7, 0xBE, 0xFF, 0xFF, 0xFD, 0x20, 0xFD, 0x20, 0xFD, 0x20, 0xFD, 0x20, 0xFD, 0x20, 
		0xD6, 0xDA, 0xF7, 0xBE, 0xEF, 0x7D, 0xCE, 0x59, 0xAD, 0x75, 0xA5, 0x34, 0xAD, 0x75, 0xCE, 0x59, 0xEF, 0x7D, 0xF7, 0xBE, 0xE7, 0x5C, 0xDF, 0x1B, 0xDF, 0x1B, 0xDF, 0x1B, 0xE7, 0x5C, 0xF7, 0xBE};

const prog_uchar MINUS[] PROGMEM ={
		0x18, 0x18, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD7, 0x5E, 0xB6, 0xBD, 0x96, 0x1C, 0x8D, 0xDB, 0x85, 0xDB, 0x85, 0xDB, 0x96, 0x1C, 0xB6, 0xBD, 0xD7, 0x5E, 0xF7, 0xDF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0x1D, 0x8D, 0xDB, 0x95, 0xDB, 0x84, 0xD8, 0x63, 0xD6, 0x53, 0x55, 0x53, 0x55, 0x53, 0x75, 
		0x63, 0xD6, 0x74, 0x98, 0x85, 0x9B, 0x8D, 0xDB, 0xCF, 0x1E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9E, 0x8D, 0xDB, 0x74, 0xF9, 0x53, 0x75, 0x32, 0xB3, 
		0x2A, 0x73, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x5B, 0xB6, 0x74, 0xF9, 0x96, 0x1C, 0xE7, 0x7E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x7E, 
		0x7D, 0x3A, 0x5C, 0x17, 0x2A, 0x52, 0x2A, 0x73, 0x32, 0xB3, 0x3A, 0xD4, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x4B, 0x34, 0x53, 0x55, 0x53, 0x55, 0x53, 0x55, 0x53, 0x55, 0x6C, 0x37, 0x7D, 0xBB, 0xD6, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9E, 0x6D, 0x5A, 0x4B, 0x34, 0x22, 0x52, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x4B, 0x34, 0x53, 0x55, 0x53, 0x55, 0x53, 0x75, 0x5B, 0xB6, 
		0x53, 0x75, 0x63, 0xD6, 0x7D, 0x3A, 0xE7, 0x7E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0xBB, 0x43, 0x75, 0x22, 0x32, 0x2A, 0x73, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x4B, 0x34, 
		0x53, 0x55, 0x53, 0x55, 0x53, 0x75, 0x53, 0x75, 0x5B, 0xB6, 0x5B, 0xB6, 0x5B, 0xB6, 0x6C, 0x37, 0x85, 0xDB, 0xF7, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 0xCF, 0x1D, 0x43, 0xB6, 0x22, 0x32, 0x2A, 0x73, 0x2A, 0x73, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 
		0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x4B, 0x34, 0x53, 0x55, 0x53, 0x55, 0x53, 0x75, 0x5B, 0xB6, 0x5B, 0xB6, 0x63, 0xD6, 0x63, 0xD6, 0x63, 0xD6, 0x6C, 0x37, 0xB6, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0x6C, 0xD9, 0x32, 0x93, 0x22, 0x52, 
		0x2A, 0x73, 0x2A, 0x73, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x4B, 0x34, 0x53, 0x55, 0x53, 0x55, 0x53, 0x75, 0x5B, 0xB6, 0x5B, 0xB6, 0x63, 0xD6, 0x63, 0xD6, 0x6C, 0x37, 0x63, 0xD6, 0x5C, 0xD9, 
		0xEF, 0x9E, 0xD7, 0x5E, 0x43, 0xB6, 0x22, 0x12, 0x22, 0x52, 0x2A, 0x73, 0x2A, 0x73, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x53, 0x55, 0x53, 0x55, 0x53, 0x75, 0x5B, 0xB6, 0x5B, 0xB6, 
		0x63, 0xD6, 0x63, 0xD6, 0x63, 0xD6, 0x32, 0x93, 0x3A, 0xD4, 0xBE, 0xDD, 0xA6, 0x9C, 0x32, 0xB3, 0x22, 0x12, 0x22, 0x32, 0x22, 0x52, 0x2A, 0x73, 0x22, 0x52, 0x22, 0x52, 0x2A, 0x73, 0x32, 0x93, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 
		0x4B, 0x34, 0x4B, 0x34, 0x4B, 0x34, 0x42, 0xF4, 0x4B, 0x34, 0x53, 0x75, 0x53, 0x75, 0x2A, 0x73, 0x19, 0xF2, 0x22, 0x32, 0x7D, 0xBB, 0x6C, 0xB9, 0x2A, 0x73, 0x22, 0x12, 0x22, 0x32, 0x22, 0x32, 0x22, 0x32, 0x6C, 0x37, 0xAD, 0xBA, 0xB6, 0x3A, 
		0xBE, 0x5B, 0xC6, 0x7C, 0xC6, 0x9C, 0xC6, 0x9C, 0xC6, 0x9C, 0xC6, 0x9C, 0xC6, 0x7C, 0xBE, 0x5B, 0xB6, 0x3A, 0x95, 0x39, 0x53, 0x55, 0x22, 0x12, 0x22, 0x12, 0x22, 0x32, 0x22, 0x32, 0x5C, 0xD9, 0x4C, 0x17, 0x2A, 0x73, 0x22, 0x32, 0x22, 0x32, 
		0x19, 0xF2, 0x42, 0xF4, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0x7C, 0x22, 0x12, 0x22, 0x32, 0x22, 0x32, 0x22, 0x32, 
		0x4C, 0x17, 0x43, 0xB6, 0x2A, 0x73, 0x22, 0x12, 0x22, 0x32, 0x19, 0xF2, 0x5B, 0xB6, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xD6, 0xDC, 0x2A, 0x53, 0x2A, 0x73, 0x22, 0x52, 0x22, 0x32, 0x43, 0xB6, 0x4C, 0x17, 0x32, 0x93, 0x22, 0x32, 0x22, 0x52, 0x2A, 0x53, 0x32, 0xB3, 0xD6, 0xDC, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x95, 0x39, 0x2A, 0x73, 0x32, 0xB3, 0x32, 0x93, 0x2A, 0x73, 0x43, 0xB6, 0x64, 0x79, 0x42, 0xF4, 0x22, 0x52, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x42, 0xF4, 0x6C, 0x37, 0x74, 0x77, 
		0x74, 0x77, 0x74, 0x77, 0x74, 0x77, 0x74, 0x98, 0x74, 0x98, 0x74, 0x98, 0x74, 0x98, 0x74, 0x77, 0x74, 0x77, 0x63, 0xD6, 0x3A, 0xD4, 0x42, 0xF4, 0x3A, 0xD4, 0x32, 0xB3, 0x32, 0xB3, 0x4C, 0x17, 0x96, 0x1C, 0x43, 0x75, 0x32, 0x93, 0x32, 0xB3, 
		0x3A, 0xD4, 0x42, 0xF4, 0x43, 0x35, 0x43, 0x35, 0x43, 0x35, 0x43, 0x35, 0x43, 0x35, 0x43, 0x75, 0x43, 0x75, 0x43, 0x75, 0x43, 0x75, 0x43, 0x75, 0x43, 0x75, 0x43, 0x35, 0x43, 0x35, 0x43, 0x75, 0x43, 0x35, 0x43, 0x35, 0x3A, 0xD4, 0x43, 0x35, 
		0x65, 0x1A, 0xCF, 0x1D, 0x4C, 0x17, 0x42, 0xF4, 0x3A, 0xD4, 0x43, 0x35, 0x43, 0x35, 0x43, 0x75, 0x43, 0x75, 0x4B, 0xB6, 0x4B, 0xB6, 0x4B, 0xB6, 0x53, 0xF7, 0x53, 0xF7, 0x53, 0xF7, 0x53, 0xF7, 0x53, 0xF7, 0x53, 0xF7, 0x4B, 0xB6, 0x4B, 0xB6, 
		0x4B, 0xB6, 0x43, 0x75, 0x43, 0x75, 0x43, 0x35, 0x43, 0xB6, 0xA6, 0x5C, 0xF7, 0xDF, 0x54, 0x98, 0x53, 0xF7, 0x42, 0xF4, 0x43, 0x35, 0x43, 0x75, 0x4B, 0xB6, 0x4B, 0xB6, 0x53, 0xF7, 0x5C, 0x17, 0x5C, 0x17, 0x5C, 0x17, 0x5C, 0x38, 0x5C, 0x38, 
		0x5C, 0x38, 0x5C, 0x38, 0x5C, 0x17, 0x5C, 0x17, 0x53, 0xF7, 0x53, 0xF7, 0x4B, 0xB6, 0x43, 0x75, 0x4B, 0xB6, 0x43, 0xB6, 0xE7, 0x7E, 0xFF, 0xFF, 0xB6, 0xBD, 0x54, 0x98, 0x53, 0xF7, 0x43, 0x75, 0x4B, 0xB6, 0x53, 0xF7, 0x5C, 0x17, 0x5C, 0x17, 
		0x5C, 0x38, 0x5C, 0x38, 0x64, 0x78, 0x64, 0x78, 0x64, 0x78, 0x64, 0x78, 0x64, 0x78, 0x64, 0x78, 0x5C, 0x38, 0x5C, 0x38, 0x5C, 0x17, 0x53, 0xF7, 0x53, 0xF7, 0x5C, 0x38, 0x8D, 0xDB, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x65, 0x1A, 0x6C, 0xD9, 
		0x5C, 0x17, 0x53, 0xF7, 0x5C, 0x17, 0x5C, 0x38, 0x64, 0x78, 0x64, 0x78, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xB9, 0x64, 0x78, 0x64, 0x78, 0x5C, 0x38, 0x6C, 0xB9, 0x54, 0x98, 0xEF, 0x9E, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD7, 0x5E, 0x5C, 0xD9, 0x7D, 0x3A, 0x64, 0x78, 0x5C, 0x38, 0x64, 0x78, 0x6C, 0xB9, 0x6C, 0xB9, 0x6C, 0xD9, 0x74, 0xF9, 0x74, 0xF9, 0x74, 0xF9, 0x74, 0xF9, 0x74, 0xF9, 0x74, 0xF9, 0x6C, 0xD9, 0x6C, 0xB9, 
		0x6C, 0xB9, 0x74, 0xF9, 0x5C, 0xD9, 0xBE, 0xDD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD6, 0xFE, 0x65, 0x1A, 0x85, 0x9B, 0x7D, 0x3A, 0x6C, 0xD9, 0x6C, 0xB9, 0x6C, 0xD9, 0x74, 0xF9, 0x7D, 0x3A, 0x7D, 0x3A, 0x7D, 0x3A, 
		0x7D, 0x3A, 0x7D, 0x3A, 0x7D, 0x3A, 0x7D, 0x3A, 0x7D, 0x3A, 0x85, 0x9B, 0x65, 0x1A, 0xB6, 0x3A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD7, 0x5E, 0x6D, 0x5A, 0x8D, 0xDB, 0xA6, 0x5C, 0x96, 0x1C, 
		0x95, 0xDB, 0x85, 0x9B, 0x85, 0x9B, 0x85, 0x9B, 0x85, 0x9B, 0x85, 0x9B, 0x95, 0xDB, 0x96, 0x1C, 0xA6, 0x5C, 0x96, 0x1C, 0x6D, 0x5A, 0xBE, 0xDD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xF7, 0xDF, 0xA6, 0x5C, 0x6D, 0x5A, 0xA6, 0x9C, 0xCF, 0x1E, 0xD7, 0x5E, 0xE7, 0x7E, 0xEF, 0x9E, 0xE7, 0x7E, 0xD7, 0x5E, 0xCF, 0x1E, 0xB6, 0xBD, 0x7D, 0xBB, 0x95, 0xDB, 0xEF, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9E, 0xB6, 0xBD, 0x85, 0x9B, 0x8D, 0xDB, 0xA6, 0x5C, 0xA6, 0x9C, 0xA6, 0x5C, 0x8D, 0xDB, 0x85, 0x9B, 0xA6, 0x9C, 0xE7, 0x7E, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};

const prog_uchar PLUS[] PROGMEM ={
		0x18, 0x18, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBF, 0xCF, 0x1E, 0xAE, 0x9D, 0xAE, 0x9D, 0xAE, 0x9D, 0xCF, 0x3E, 0xEF, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xDF, 0xCF, 0x1E, 0x9E, 0x3C, 0x8D, 0xDB, 0x95, 0xDB, 0x95, 0xDB, 0x85, 0xBB, 
		0x85, 0xBB, 0x9E, 0x3C, 0xCF, 0x3E, 0xF7, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xBE, 0xDD, 0x85, 0xBB, 0x8D, 0x19, 
		0x5B, 0x95, 0x42, 0xF4, 0x42, 0xF4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x5B, 0xB6, 0x84, 0xB8, 0x85, 0xBB, 0xBE, 0xDD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0x85, 0xBB, 0x74, 0xB8, 0x42, 0xF4, 0x2A, 0x52, 0x32, 0x93, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x42, 0xF4, 0x4B, 0x34, 0x4B, 0x34, 0x4B, 0x34, 0x5B, 0x95, 0x74, 0xB8, 0x9E, 0x3C, 0xF7, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x85, 0x7A, 0x53, 0xD6, 0x2A, 0x52, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x3A, 0xD4, 0x42, 0xF4, 0x4B, 0x34, 0x53, 0x75, 0x53, 0x75, 0x5B, 0x95, 0x53, 0x75, 
		0x6C, 0x37, 0x85, 0xBB, 0xF7, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7D, 0x9A, 0x43, 0x76, 0x22, 0x32, 0x32, 0x93, 0x32, 0x93, 0x32, 0xB3, 0x32, 0xB3, 0x3A, 0xD4, 0x42, 0xF4, 0x84, 0xB8, 0x84, 0xB8, 
		0x4B, 0x34, 0x53, 0x75, 0x53, 0x75, 0x5B, 0x95, 0x5B, 0xB6, 0x5B, 0xB6, 0x6C, 0x37, 0x7D, 0x9A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xB6, 0xBD, 0x4B, 0x96, 0x22, 0x32, 0x2A, 0x73, 0x32, 0x93, 0x32, 0x93, 0x32, 0xB3, 
		0x3A, 0xD4, 0x32, 0xB3, 0x63, 0xF6, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x77, 0x4B, 0x34, 0x5B, 0x95, 0x5B, 0xB6, 0x5B, 0xB6, 0x63, 0xF6, 0x63, 0xF6, 0x6C, 0x37, 0xA6, 0xBD, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBF, 0x54, 0xD9, 0x2A, 0x52, 
		0x2A, 0x52, 0x2A, 0x73, 0x32, 0x93, 0x32, 0x93, 0x32, 0xB3, 0x3A, 0xD4, 0x32, 0xB3, 0x74, 0x77, 0xFF, 0xFF, 0xFF, 0xFF, 0x84, 0xB8, 0x4B, 0x34, 0x5B, 0x95, 0x5B, 0xB6, 0x5B, 0xB6, 0x63, 0xF6, 0x63, 0xF6, 0x63, 0xF6, 0x64, 0xB9, 0xF7, 0xBF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0xDC, 0x3B, 0x15, 0x21, 0xF2, 0x2A, 0x52, 0x2A, 0x73, 0x32, 0x93, 0x32, 0x93, 0x32, 0xB3, 0x3A, 0xD4, 0x32, 0xB3, 0x84, 0xB8, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x77, 0x4B, 0x34, 0x5B, 0x95, 0x5B, 0xB6, 0x5B, 0xB6, 
		0x63, 0xF6, 0x6C, 0x37, 0x53, 0x75, 0x32, 0x93, 0xA6, 0x5C, 0xFF, 0xFF, 0xEF, 0x9E, 0x85, 0x7A, 0x2A, 0x52, 0x22, 0x12, 0x22, 0x32, 0x2A, 0x73, 0x32, 0x93, 0x2A, 0x52, 0x2A, 0x52, 0x32, 0x93, 0x2A, 0x52, 0x84, 0xB8, 0xFF, 0xFF, 0xFF, 0xFF, 
		0x6C, 0x37, 0x4B, 0x34, 0x53, 0x75, 0x5B, 0x95, 0x5B, 0xB6, 0x63, 0xF6, 0x4B, 0x34, 0x22, 0x12, 0x22, 0x32, 0x64, 0xF9, 0xCF, 0x3E, 0xBE, 0xDD, 0x4C, 0x38, 0x22, 0x32, 0x22, 0x32, 0x22, 0x32, 0x22, 0x32, 0x2A, 0x73, 0x74, 0x77, 0x8D, 0x19, 
		0x84, 0xB8, 0x6C, 0x37, 0xAD, 0xDA, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x77, 0x5B, 0xB6, 0x5B, 0xB6, 0x5B, 0xB6, 0x4B, 0x34, 0x2A, 0x73, 0x22, 0x12, 0x22, 0x12, 0x21, 0xF2, 0x43, 0x76, 0xA6, 0x5C, 0x9E, 0x3C, 0x43, 0x76, 0x22, 0x32, 0x22, 0x32, 
		0x22, 0x32, 0x21, 0xF2, 0x63, 0xF6, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xDF, 0xEF, 0x9E, 0xEF, 0x9E, 0xAD, 0xDA, 0x21, 0xF2, 0x22, 0x32, 0x22, 0x32, 0x21, 0xF2, 0x3A, 0xD4, 
		0x95, 0xDB, 0x8D, 0xDB, 0x43, 0x76, 0x22, 0x32, 0x22, 0x32, 0x22, 0x32, 0x22, 0x12, 0x4B, 0x34, 0xE7, 0x5E, 0xF7, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF, 0x3D, 
		0x2A, 0x52, 0x2A, 0x73, 0x2A, 0x52, 0x22, 0x32, 0x3A, 0xD4, 0x85, 0xBB, 0x9E, 0x3C, 0x43, 0x76, 0x22, 0x32, 0x22, 0x32, 0x2A, 0x52, 0x32, 0x93, 0x2A, 0x73, 0x3A, 0xD4, 0x53, 0x75, 0x5B, 0xD6, 0x5B, 0xD6, 0xBE, 0x5C, 0xFF, 0xFF, 0xEF, 0x9E, 
		0x8D, 0x19, 0x9D, 0x5A, 0x9D, 0x5A, 0x9D, 0x5A, 0x5B, 0xD6, 0x32, 0xB3, 0x32, 0xB3, 0x32, 0x93, 0x2A, 0x73, 0x3B, 0x15, 0x85, 0xBB, 0xB6, 0xBD, 0x4C, 0x38, 0x32, 0x93, 0x2A, 0x73, 0x32, 0x93, 0x32, 0xB3, 0x3A, 0xD4, 0x3A, 0xD4, 0x3B, 0x15, 
		0x3B, 0x15, 0x3A, 0xD4, 0xB6, 0x1B, 0xFF, 0xFF, 0xE7, 0x5E, 0x3B, 0x15, 0x3B, 0x15, 0x3B, 0x15, 0x3A, 0xD4, 0x3B, 0x15, 0x3B, 0x15, 0x3A, 0xD4, 0x3A, 0xD4, 0x32, 0xB3, 0x43, 0x76, 0x9E, 0x3C, 0xEF, 0x9E, 0x75, 0x39, 0x4B, 0x34, 0x32, 0x93, 
		0x3A, 0xD4, 0x3A, 0xD4, 0x3B, 0x15, 0x3B, 0x15, 0x43, 0x76, 0x4B, 0x96, 0x43, 0x76, 0xBE, 0x5C, 0xFF, 0xFF, 0xDF, 0x3D, 0x4B, 0x96, 0x4B, 0x96, 0x4B, 0x96, 0x4B, 0x96, 0x43, 0x76, 0x43, 0x76, 0x3B, 0x15, 0x3B, 0x15, 0x3B, 0x15, 0x4C, 0x38, 
		0xC6, 0xDC, 0xFF, 0xFF, 0xB6, 0xBD, 0x54, 0x17, 0x3A, 0xD4, 0x3B, 0x15, 0x3B, 0x15, 0x43, 0x76, 0x4B, 0x96, 0x4B, 0x96, 0x53, 0xD6, 0x4B, 0x96, 0xC6, 0xDC, 0xFF, 0xFF, 0xD6, 0xFD, 0x53, 0xD6, 0x54, 0x17, 0x53, 0xD6, 0x53, 0xD6, 0x53, 0xD6, 
		0x4B, 0x96, 0x4B, 0x96, 0x43, 0x76, 0x4B, 0x96, 0x8D, 0xDB, 0xF7, 0xDF, 0xFF, 0xFF, 0xEF, 0x9E, 0x4C, 0x38, 0x53, 0xD6, 0x3B, 0x15, 0x43, 0x76, 0x4B, 0x96, 0x53, 0xD6, 0x53, 0xD6, 0x54, 0x17, 0x53, 0xD6, 0xAD, 0xDA, 0xFF, 0xFF, 0xBE, 0x5C, 
		0x54, 0x17, 0x5C, 0x38, 0x5C, 0x38, 0x54, 0x17, 0x54, 0x17, 0x53, 0xD6, 0x4B, 0x96, 0x53, 0xD6, 0x4B, 0xF7, 0xE7, 0x5E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xA6, 0x5C, 0x64, 0xB9, 0x53, 0xD6, 0x4B, 0x96, 0x53, 0xD6, 0x54, 0x17, 0x5C, 0x38, 
		0x5C, 0x38, 0x64, 0x78, 0x5C, 0x38, 0x74, 0xB8, 0x64, 0x78, 0x64, 0xB9, 0x64, 0x78, 0x64, 0x78, 0x64, 0x78, 0x5C, 0x38, 0x54, 0x17, 0x54, 0x17, 0x64, 0x78, 0x75, 0x3A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0xF9, 
		0x74, 0xFA, 0x5C, 0x38, 0x54, 0x17, 0x5C, 0x38, 0x64, 0x78, 0x64, 0xB9, 0x64, 0xB9, 0x6C, 0xD9, 0x6C, 0xD9, 0x6C, 0xD9, 0x6C, 0xD9, 0x6C, 0xD9, 0x6C, 0xD9, 0x64, 0xB9, 0x64, 0x78, 0x64, 0x78, 0x74, 0xFA, 0x54, 0xD9, 0xF7, 0xBF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9E, 0x64, 0xF9, 0x85, 0x7A, 0x74, 0xFA, 0x64, 0x78, 0x64, 0xB9, 0x6C, 0xD9, 0x74, 0xFA, 0x74, 0xFA, 0x75, 0x3A, 0x75, 0x3A, 0x75, 0x3A, 0x75, 0x3A, 0x74, 0xFA, 0x74, 0xFA, 0x74, 0xFA, 
		0x85, 0x7A, 0x64, 0xF9, 0xCF, 0x3E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9E, 0x6D, 0x39, 0x85, 0xBB, 0x95, 0xDB, 0x85, 0x7A, 0x85, 0x7A, 0x75, 0x3A, 0x75, 0x3A, 0x75, 0x3A, 0x85, 0x7A, 
		0x85, 0x7A, 0x85, 0x7A, 0x85, 0xBB, 0x95, 0xDB, 0x8D, 0xDB, 0x6D, 0x39, 0xCF, 0x3E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x95, 0xDB, 0x7D, 0x9A, 0xAE, 0x9D, 
		0xCF, 0x1E, 0xCF, 0x1E, 0xCF, 0x1E, 0xCF, 0x1E, 0xCF, 0x1E, 0xCF, 0x1E, 0xCF, 0x1E, 0xAE, 0x9D, 0x8D, 0xDB, 0x7D, 0x9A, 0xF7, 0xBF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9E, 0x9E, 0x3C, 0x7D, 0x9A, 0x9E, 0x3C, 0xBE, 0xDD, 0xCF, 0x3E, 0xCF, 0x1E, 0xA6, 0x5C, 0x7D, 0x9A, 0x95, 0xDB, 0xEF, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC6, 0xDC, 0x9E, 0x3C, 0x9E, 0x3C, 0x9E, 0x3C, 0x9E, 0x3C, 0x9E, 0x3C, 0xC6, 0xDC, 0xF7, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};

const prog_uchar ATOTIMEOUTFLAG[] PROGMEM ={
		0xF, 0xF, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0x38, 0xCB, 0x6C, 0xB9, 0xA5, 0xB9, 0x44, 0xB9, 0xA5, 0xCB, 0x6C, 0xEE, 0x38, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xF7, 0x3C, 0xD4, 0xF, 0xC2, 0xA9, 0xE5, 0xD6, 0xF7, 0x3C, 0xA9, 0x85, 0xEE, 0x18, 0xDD, 0x13, 0xC2, 0x89, 0xD4, 0xF, 0xF7, 0x3C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xBA, 0xB1, 0x64, 0xDC, 0xB2, 0xFF, 0xDE, 0xFF, 0xDF, 
		0xF7, 0x9E, 0xC3, 0x6D, 0xEE, 0x38, 0xEE, 0x38, 0xEE, 0x38, 0xD4, 0x50, 0xB1, 0x64, 0xEE, 0xBA, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD3, 0xEF, 0xDD, 0x34, 0xF7, 0xDE, 0xF7, 0xBE, 0xF7, 0xBE, 0xF7, 0xBE, 0xCD, 0x75, 0xE6, 0x38, 0xE6, 0x38, 
		0xE6, 0x38, 0xE6, 0x38, 0xD4, 0xB2, 0xD3, 0xEF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0x59, 0xC2, 0xCA, 0xF7, 0xBE, 0xF7, 0xBE, 0xF7, 0x9E, 0xF7, 0x9E, 0xF7, 0x9E, 0xA4, 0x71, 0xE6, 0x17, 0xE6, 0x17, 0xE6, 0x17, 0xE6, 0x17, 0xE6, 0x38, 0xBA, 0xAA, 
		0xEE, 0x59, 0xFF, 0xFF, 0xCB, 0x8D, 0xDD, 0x75, 0xF7, 0x9E, 0xEF, 0x9D, 0xEF, 0x9D, 0xEF, 0x9D, 0xEF, 0x9D, 0x7B, 0x6D, 0xE6, 0x17, 0xE6, 0x17, 0xE6, 0x17, 0xE6, 0x17, 0xE6, 0x17, 0xD4, 0xD2, 0xCB, 0x8D, 0xFF, 0xFF, 0xB1, 0xC6, 0xEF, 0x1B, 
		0xEF, 0x7D, 0xEF, 0x7D, 0xEF, 0x7D, 0xEF, 0x7D, 0xEF, 0x7D, 0x5A, 0x8A, 0xDD, 0xF7, 0xDD, 0xF7, 0xDD, 0xF7, 0xDD, 0xF7, 0xDD, 0xF7, 0xDD, 0xB6, 0xB1, 0xE7, 0xFF, 0xFF, 0xA1, 0x24, 0xA9, 0xA6, 0xBB, 0x6D, 0xEF, 0x5D, 0xEF, 0x5D, 0xEF, 0x5D, 
		0xEF, 0x5D, 0x31, 0x86, 0xDD, 0xD6, 0xDD, 0xD6, 0xDD, 0xD6, 0xDD, 0xD6, 0xCC, 0x50, 0xA9, 0x44, 0xA9, 0x44, 0xFF, 0xFF, 0xA9, 0xC7, 0xE6, 0xBA, 0xE7, 0x3C, 0xE7, 0x3C, 0xE7, 0x3C, 0xE7, 0x3C, 0xE7, 0x3C, 0x29, 0x25, 0xA4, 0x71, 0xDD, 0xD6, 
		0xDD, 0xD6, 0xDD, 0xD6, 0xDD, 0xD6, 0xDD, 0x95, 0xA9, 0xC7, 0xFF, 0xFF, 0xC3, 0x8D, 0xD5, 0x34, 0xE7, 0x3C, 0xE7, 0x3C, 0xE7, 0x3C, 0xE7, 0x3C, 0xE7, 0x1C, 0xC5, 0x75, 0x52, 0x28, 0xCD, 0x75, 0xD5, 0xB6, 0xD5, 0xB6, 0xD5, 0xB6, 0xCC, 0x91, 
		0xC3, 0x8D, 0xFF, 0xFF, 0xE6, 0x59, 0xAA, 0x28, 0xE6, 0xFB, 0xDF, 0x1B, 0xDF, 0x1B, 0xDF, 0x1B, 0xD6, 0x17, 0xD5, 0xB6, 0xCD, 0x75, 0x94, 0x10, 0xD5, 0xB6, 0xD5, 0xB6, 0xD5, 0x96, 0xAA, 0x28, 0xE6, 0x59, 0xFF, 0xFF, 0xFF, 0xFF, 0xC4, 0x10, 
		0xBC, 0xF, 0xDE, 0xFB, 0xDE, 0xFB, 0xD5, 0xF7, 0xD5, 0x95, 0xD5, 0x95, 0xD5, 0x95, 0xD5, 0x75, 0xD5, 0x95, 0xD5, 0x96, 0xBB, 0xAE, 0xC4, 0x10, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0x7D, 0x99, 0x4, 0xBB, 0xEF, 0xD5, 0xD6, 0xD5, 0x95, 
		0xD5, 0x75, 0xC3, 0xEF, 0xD5, 0x95, 0xD5, 0x95, 0xD5, 0x75, 0xBB, 0x8E, 0x99, 0x4, 0xF7, 0x7D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0x7D, 0xC4, 0x10, 0xA2, 0x8, 0xBC, 0xF, 0xC4, 0x91, 0xA9, 0x85, 0xC4, 0xD2, 0xBC, 0xF, 
		0xA2, 0x8, 0xC4, 0x10, 0xF7, 0x7D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEE, 0xBA, 0xC3, 0xEF, 0xAA, 0x8A, 0x99, 0x66, 0xAA, 0x8A, 0xC3, 0xEF, 0xEE, 0xBA, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};

const prog_uchar OVERHEATFLAG[] PROGMEM ={
		0xF, 0xF, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xD6, 0xFC, 0x74, 0xD6, 0x74, 0xD6, 0x7C, 0xF6, 0xD7, 0x1C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0x6C, 0x54, 0xDF, 0x7F, 0xDF, 0x9F, 0xEF, 0xDF, 0x7D, 0x17, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x54, 0xD7, 0x5E, 
		0x9E, 0x5D, 0xE7, 0xDF, 0x7C, 0xF6, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x54, 0xAD, 0xD8, 0x7D, 0x17, 0xE7, 0xDF, 0x7C, 0xF6, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x54, 0xD7, 0x5F, 0x9E, 0x7D, 0xE7, 0xDF, 0x7C, 0xF6, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x54, 0xD7, 0x5F, 0x9E, 0x7E, 0xE7, 0xDF, 0x7C, 0xF6, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x54, 0xAD, 0xD9, 0x9D, 0x31, 0xE7, 0xDF, 0x7C, 0xF6, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x54, 0xD7, 0x5F, 
		0xF5, 0xA0, 0xE7, 0xDF, 0x7C, 0xF7, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x64, 0x34, 0xD7, 0x7F, 0xED, 0x60, 0xE7, 0xDF, 0x7C, 0xF7, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xAD, 0xD9, 0x7D, 0x17, 0x95, 0xBB, 0xE5, 0x40, 0xCF, 0x9F, 0x8D, 0x79, 0xA5, 0xD9, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x6C, 0x54, 0xB6, 0xDF, 0xE5, 0xC7, 0xDD, 0x1, 0xEE, 0x26, 0xD7, 0x9F, 0x64, 0x54, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0x64, 0x54, 0xBE, 0xBC, 0xE5, 0x41, 0xE5, 0x62, 0xF5, 0xA0, 0xD7, 0xBF, 0x64, 0x34, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x74, 0x95, 0x96, 0x3E, 0xD5, 0x46, 
		0xE5, 0x20, 0xE5, 0xC6, 0xBF, 0x5F, 0x6C, 0x54, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x95, 0x36, 0x74, 0xD6, 0x9E, 0x5E, 0xA6, 0xDF, 0xAE, 0xFF, 0x7D, 0x17, 0x95, 0x36, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF, 0x1B, 0x95, 0x36, 0x6C, 0x54, 0x6C, 0x54, 0x6C, 0x54, 0x95, 0x36, 0xDF, 0x1B, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF, 0x1B, 0xCE, 0x59, 0xCE, 0x59, 0xCE, 0x59, 0xDF, 0x1B, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const prog_uchar BUSLOCKFLAG[] PROGMEM ={
		0xF, 0xF, 0x05, 0x02, 0x00, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 
		0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0x7B, 0xEF, 0xFF, 0xFF, 0x73, 0xAE, 0xFF, 0xFF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0xFF, 0xDF, 0x73, 0xAE, 
		0xFF, 0xFF, 0x6B, 0x4D, 0xF7, 0xBE, 0x41, 0xE8, 0x41, 0xE8, 0xEF, 0x7D, 0x41, 0xE8, 0x41, 0xE8, 0xEF, 0x7D, 0x41, 0xE8, 0x41, 0xE8, 0xEF, 0x7D, 0x41, 0xE8, 0x41, 0xE8, 0xEF, 0x7D, 0x6B, 0x4D, 0xFF, 0xFF, 0x5A, 0xCB, 0xEF, 0x7D, 0x8C, 0x71, 
		0x8C, 0x71, 0xDE, 0xFB, 0x8C, 0x71, 0x8C, 0x71, 0xDE, 0xFB, 0x8C, 0x71, 0x8C, 0x71, 0xDE, 0xFB, 0x8C, 0x71, 0x8C, 0x71, 0xDE, 0xFB, 0x5A, 0xCB, 0xFF, 0xFF, 0x4A, 0x49, 0xEF, 0x7D, 0xEF, 0x7E, 0xEF, 0x5E, 0xDF, 0x1C, 0xE7, 0x3E, 0xE7, 0x3E, 
		0xDE, 0xFC, 0xE7, 0x3E, 0xE7, 0x3E, 0xDE, 0xFC, 0xE7, 0x3E, 0xE7, 0x3E, 0xDE, 0xFC, 0x4A, 0x49, 0xFF, 0xFF, 0x29, 0x65, 0x21, 0x24, 0x21, 0x24, 0x21, 0x24, 0x21, 0x24, 0x21, 0x24, 0x21, 0x24, 0x10, 0x82, 0x21, 0x24, 0x21, 0x24, 0x21, 0x24, 
		0x21, 0x24, 0x21, 0x24, 0x21, 0x24, 0x29, 0x65, 0xFF, 0xFF, 0x18, 0xC3, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xA3, 0x8, 0x21, 0x0, 0x0, 0x8, 0x21, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xA3, 0x18, 0xC3, 
		0xFF, 0xFF, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x5, 0x23, 0x2, 0x81, 0x5, 0x23, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0xFF, 0xFF, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 
		0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x2, 0x61, 0x57, 0x4C, 0x2, 0x61, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0xFF, 0xFF, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x3, 0x41, 
		0x4, 0x1, 0x3, 0x41, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0x0, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};
const prog_uchar LIGHTSONFLAG[] PROGMEM ={
		0xF, 0xF, 0x05, 0x02, 0x00,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0x7C, 0xD5, 0x8E, 0xCC, 0xC8, 0xCC, 0xC8, 0xCC, 0xC8, 0xCC, 0xC8, 0xD5, 0x8E, 0xF7, 0x7C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xDF,
		0xE6, 0xB7, 0xCD, 0x9, 0xEE, 0x2E, 0xFF, 0xFE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFE, 0xEE, 0x2E, 0xCD, 0x9, 0xE6, 0xB7, 0xFF, 0xDF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x1A, 0xD5, 0xA, 0xF6, 0x4C, 0xFF, 0x9A, 0xFF, 0xBB,
		0xFF, 0x9B, 0xFF, 0x9B, 0xFF, 0xBB, 0xFF, 0xBB, 0xF6, 0x4C, 0xD5, 0xA, 0xEF, 0x1A, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBE, 0xD5, 0x6D, 0xEE, 0x2D, 0xFE, 0xAE, 0xFF, 0x78, 0xFF, 0x57, 0xFF, 0x57, 0xFF, 0x57, 0xFF, 0x57, 0xFF, 0x78,
		0xFE, 0xAE, 0xEE, 0x2D, 0xD5, 0x6D, 0xF7, 0xBE, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7D, 0xD5, 0x29, 0xFE, 0xD0, 0xF6, 0xAF, 0xFF, 0x35, 0xFF, 0x35, 0xFF, 0x35, 0xFF, 0x35, 0xFF, 0x35, 0xFF, 0x35, 0xF6, 0xAF, 0xFE, 0xD0, 0xD5, 0x29, 0xEF, 0x7D,
		0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5C, 0xDD, 0x6B, 0xFE, 0xF2, 0xFE, 0xD1, 0xFE, 0xF1, 0xC5, 0xD1, 0xFF, 0x13, 0xFF, 0x13, 0xC5, 0xD1, 0xFE, 0xF1, 0xFE, 0xD1, 0xFE, 0xF2, 0xDD, 0x6B, 0xE7, 0x5C, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5C, 0xD5, 0x29,
		0xFF, 0x13, 0xFE, 0xF2, 0xB5, 0x4F, 0xFE, 0xF2, 0xBD, 0x90, 0xBD, 0x90, 0xFE, 0xF2, 0xB5, 0x4F, 0xFE, 0xF2, 0xFF, 0x13, 0xD5, 0x29, 0xE7, 0x5C, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5C, 0xD5, 0x6C, 0xEE, 0x70, 0xFF, 0x34, 0xBD, 0xD1, 0xFF, 0x13,
		0xFF, 0x13, 0xFF, 0x13, 0xFF, 0x13, 0xBD, 0xD1, 0xFF, 0x34, 0xEE, 0x70, 0xD5, 0x6C, 0xE7, 0x5C, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x7D, 0xCE, 0x15, 0xDD, 0x6A, 0xF6, 0xF3, 0xD6, 0x94, 0xF7, 0x15, 0xF7, 0x14, 0xF7, 0x14, 0xF7, 0x15, 0xD6, 0x94,
		0xF6, 0xF3, 0xDD, 0x6A, 0xCE, 0x15, 0xEF, 0x7D, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0xBE, 0xDE, 0xFB, 0xC5, 0xD5, 0xDD, 0x8B, 0xF6, 0xB2, 0xF7, 0x36, 0xF7, 0x36, 0xF7, 0x36, 0xF7, 0x36, 0xF6, 0xB2, 0xDD, 0x8B, 0xC5, 0xD5, 0xDE, 0xFB, 0xF7, 0xBE,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xF7, 0x9E, 0xDE, 0xFB, 0xBE, 0x17, 0xE5, 0xA9, 0xFF, 0x77, 0xFF, 0x77, 0xFF, 0x77, 0xFF, 0x98, 0xED, 0xA9, 0xBE, 0x17, 0xDE, 0xFB, 0xF7, 0x9E, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xF7, 0xBE, 0xDE, 0xFB, 0x84, 0xB5, 0x84, 0x94, 0x84, 0x94, 0x84, 0x94, 0x84, 0xB4, 0x63, 0xD2, 0xDE, 0xFB, 0xF7, 0xBE, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5C, 0x9D, 0x97, 0xAD, 0xF9,
		0xB6, 0x3B, 0x9D, 0x78, 0x84, 0xB5, 0x6B, 0xF2, 0xE7, 0x5C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xE7, 0x5C, 0x8C, 0xD4, 0x8C, 0xB4, 0x8C, 0xB3, 0x8C, 0xD4, 0x94, 0xF4, 0x73, 0xF2,
		0xE7, 0x5C, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x5D, 0xAD, 0xB7, 0xB6, 0x19, 0xBE, 0x5B, 0xA5, 0xB8, 0x8C, 0xD5, 0x8C, 0xD4, 0xEF, 0x5D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF,
		0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xEF, 0x9D, 0xCE, 0x79, 0x5B, 0x4F, 0x63, 0x70, 0x63, 0x70, 0x63, 0x90, 0xCE, 0x79, 0xEF, 0x9D, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF};

static const prog_uchar *FLAGICONS[] PROGMEM= {ATOTIMEOUTFLAG,OVERHEATFLAG,BUSLOCKFLAG,LIGHTSONFLAG};

#endif  // __RA_TOUCHLCD_H__
